@@ -3,22 +3,21 @@ use warnings;
 use strict;
 
 # ABSTRACT: Tools for generating random Dutch numbers
-our $VERSION = '1.5';
+our $VERSION = '1.6';
 
 use Exporter qw(import);
 use Carp qw(croak);
 
-our @EXPORT_OK = (
-    qw(
-        generate_bsn
-        generate_rsin
-        generate_kvk
-        generate_vestigingsnummer
-    ),
-);
+
+my @_export_person = qw(generate_bsn);
+my @_export_kvk    = qw(generate_kvk generate_rsin generate_vestigingsnummer);
+
+our @EXPORT_OK = (@_export_person, @_export_kvk);
 
 our %EXPORT_TAGS = (
-    all => \@EXPORT_OK,
+    all     => \@EXPORT_OK,
+    person  => \@_export_person,
+    company => \@_export_kvk,
 );
 
 sub generate_bsn {
@@ -134,7 +133,7 @@ Data::Random::NL - Tools for generating random Dutch numbers
 
 =head1 VERSION
 
-version 1.5
+version 1.6
 
 =head1 SYNOPSIS
 
@@ -179,6 +178,14 @@ BSN numbers in test situations start by convention with a C<9>.
 
 Get all the generate functions
 
+=item :person
+
+Imports all the numbers in use for a person
+
+=item :company
+
+Imports all the numbers in use for a company
+
 =back
 
 =head1 METHODS
